@@ -1,14 +1,13 @@
 import os
 import tensorflow as tf
 from keras.models import load_model
-from .ConfigEnum import ConfigEnum
+from .Config import Config
 
 class Brain:
 
     def __init__(self, mode=0):
-        self.config = ConfigEnum()
         self.modeSwitcher = {
-            0: self.config.get("CNN_DEFAULT_MODEL")
+            0: Config.get("CNN_DEFAULT_MODEL")
         }
         self.model = None
         self.init(self.modeSwitcher[mode])
@@ -27,6 +26,6 @@ class Brain:
         return result[prediction[0][0][0]]
 
     def predict_profiler(self, image):
-        tf.profiler.experimental.start(self.config.get("LOGS_FOLDER"))
+        tf.profiler.experimental.start(Config.get("LOGS_FOLDER"))
         self.model.predict(image)
         tf.profiler.experimental.stop()
\ No newline at end of file
