@@ -2,12 +2,11 @@ import base64
 import numpy as np
 from PIL import Image as PilImage
 from io import BytesIO
-from .ConfigEnum import ConfigEnum
+from .Config import Config
 
 
 class Image:
     def __init__(self, image=None, path=""):
-        self.config = ConfigEnum()
         if image: 
             self.image = image
         if path:
@@ -31,7 +30,7 @@ class Image:
 
     def resize(self,image):
         image = np.uint8(image)
-        image = PilImage.fromarray(image).resize((self.config.get("IMAGE_WIDTH"), self.config.get("IMAGE_HEIGHT")))
+        image = PilImage.fromarray(image).resize((Config.get("IMAGE_WIDTH"), Config.get("IMAGE_HEIGHT")))
         return np.array(image)
 
     def normalize(self, image):
